/* 
 *  gretl -- Gnu Regression, Econometrics and Time-series Library
 *  Copyright (C) 2001 Allin Cottrell and Riccardo "Jack" Lucchetti
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 * 
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

#ifndef CALCULATOR_H
#define CALCULATOR_H

typedef enum {
    C_INT,
    C_POS_INT,
    C_DBL,
    C_POS_DBL,
    C_FRAC
} EntryValType;

double entry_get_numeric_value (GtkWidget *w, EntryValType t);

void stats_calculator (gpointer p, guint code, GtkWidget *w);

#endif /* CALCULATOR_H */
